@@ -7,8 +7,8 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/goreleaser/goreleaser/internal/golden"
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/internal/golden"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"golang.org/x/sync/errgroup"
@@ -44,7 +44,6 @@ func TestAdd(t *testing.T) {
 			Type: Checksum,
 		},
 	} {
-		a := a
 		g.Go(func() error {
 			artifacts.Add(a)
 			return nil
@@ -387,7 +386,7 @@ func TestExtra(t *testing.T) {
 				Use: "docker",
 			},
 			"fail-plz": config.Homebrew{
-				Plist: "aaaa",
+				Service: "aaaa",
 			},
 			"unsupported": func() {},
 			"binaries":    []string{"foo", "bar"},
