@@ -10,13 +10,13 @@ import (
 	"testing"
 	"time"
 
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/internal/testlib"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	api "github.com/goreleaser/goreleaser/pkg/build"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	api "github.com/goreleaser/goreleaser/v2/pkg/build"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 	"github.com/stretchr/testify/require"
 )
 
@@ -522,7 +522,7 @@ func TestBuild(t *testing.T) {
 		fi, err := os.Stat(bin.Path)
 		require.NoError(t, err)
 
-		// make this a suitable map key, per docs: https://golang.org/pkg/time/#Time
+		// make this a suitable map key, per docs: https://pkg.go.dev/time#Time
 		modTime := fi.ModTime().UTC().Round(0).Unix()
 
 		if modTimes[modTime] {
@@ -1433,6 +1433,25 @@ func TestInvalidGoBinaryTpl(t *testing.T) {
 	}))
 }
 
+func TestBuildOutput(t *testing.T) {
+	t.Run("empty", func(t *testing.T) {
+		require.Empty(t, buildOutput([]byte{}))
+	})
+	t.Run("downloading only", func(t *testing.T) {
+		require.Empty(t, buildOutput([]byte(`
+go: downloading github.com/atotto/clipboard v0.1.4
+go: downloading github.com/caarlos0/duration v0.0.0-20240108180406-5d492514f3c7
+		`)))
+	})
+	t.Run("mixed", func(t *testing.T) {
+		require.NotEmpty(t, buildOutput([]byte(`
+go: downloading github.com/atotto/clipboard v0.1.4
+go: downloading github.com/caarlos0/duration v0.0.0-20240108180406-5d492514f3c7
+something something
+		`)))
+	})
+}
+
 //
 // Helpers
 //
