@@ -5,10 +5,11 @@ import (
 	"errors"
 	"fmt"
 	"net/url"
+	"path"
 	"strings"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 )
 
 // ExtractRepoFromConfig gets the repo name from the Git config.
@@ -20,10 +21,30 @@ func ExtractRepoFromConfig(ctx context.Context) (result config.Repo, err error)
 	if err != nil {
 		return result, fmt.Errorf("no remote configured to list refs from")
 	}
+	// This is a relative remote URL and requires some additional processing
+	if out == "." {
+		return extractRelativeRepoFromConfig(ctx)
+	}
 	log.WithField("rawurl", out).Debugf("got git url")
 	return ExtractRepoFromURL(out)
 }
 
+func extractRelativeRepoFromConfig(ctx context.Context) (result config.Repo, err error) {
+	out, err := Clean(Run(ctx, "rev-parse", "--abbrev-ref", "--symbolic-full-name", "@{u}"))
+	if err != nil || out == "" {
+		return result, fmt.Errorf("unable to get upstream while qualifying relative remote")
+	}
+	out, err = Clean(Run(ctx, "config", "--get", fmt.Sprintf("branch.%s.remote", out)))
+	if err != nil || out == "" {
+		return result, fmt.Errorf("unable to get upstream's remote while qualifying relative remote")
+	}
+	out, err = Clean(Run(ctx, "ls-remote", "--get-url", out))
+	if err != nil {
+		return result, fmt.Errorf("unable to get upstream while qualifying relative remote")
+	}
+	return ExtractRepoFromURL(out)
+}
+
 func ExtractRepoFromURL(rawurl string) (config.Repo, error) {
 	// removes the .git suffix and any new lines
 	s := strings.TrimSuffix(strings.TrimSpace(rawurl), ".git")
@@ -68,7 +89,7 @@ func ExtractRepoFromURL(rawurl string) (config.Repo, error) {
 	}
 	repo := config.Repo{
 		RawURL: rawurl,
-		Owner:  strings.Join(ss[:len(ss)-1], "/"),
+		Owner:  path.Join(ss[:len(ss)-1]...),
 		Name:   ss[len(ss)-1],
 	}
 	log.WithField("owner", repo.Owner).WithField("name", repo.Name).Debugf("parsed url")
