@@ -2,10 +2,11 @@ package git_test
 
 import (
 	"context"
+	"strings"
 	"testing"
 
-	"github.com/goreleaser/goreleaser/internal/git"
-	"github.com/goreleaser/goreleaser/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/internal/git"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
 	"github.com/stretchr/testify/require"
 )
 
@@ -22,6 +23,25 @@ func TestNoRemote(t *testing.T) {
 	require.EqualError(t, err, `no remote configured to list refs from`)
 }
 
+func TestRelativeRemote(t *testing.T) {
+	ctx := context.Background()
+	testlib.Mktmp(t)
+	testlib.GitInit(t)
+	testlib.GitRemoteAddWithName(t, "upstream", "https://github.com/goreleaser/goreleaser.git")
+	_, err := git.Run(ctx, "pull", "upstream", "main")
+	require.NoError(t, err)
+	_, err = git.Run(ctx, "branch", "--set-upstream-to", "upstream/main")
+	require.NoError(t, err)
+	_, err = git.Run(ctx, "checkout", "--track", "-b", "relative_branch")
+	require.NoError(t, err)
+	gitCfg, err := git.Run(ctx, "config", "--local", "--list")
+	require.NoError(t, err)
+	require.True(t, strings.Contains(gitCfg, "branch.relative_branch.remote=."))
+	repo, err := git.ExtractRepoFromConfig(ctx)
+	require.NoError(t, err)
+	require.Equal(t, "goreleaser/goreleaser", repo.String())
+}
+
 func TestRepoName(t *testing.T) {
 	testlib.Mktmp(t)
 	testlib.GitInit(t)
