@@ -2,9 +2,9 @@ package errhandler
 
 import (
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/middleware"
-	"github.com/goreleaser/goreleaser/internal/pipe"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/middleware"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 	"github.com/hashicorp/go-multierror"
 )
 
