@@ -6,17 +6,18 @@ import (
 	"testing"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/skips"
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/internal/testlib"
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/internal/skips"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/stretchr/testify/require"
 )
 
 func TestMain(m *testing.M) {
 	log.SetLevel(log.DebugLevel)
-	defer log.SetLevel(log.InfoLevel)
-	os.Exit(m.Run())
+	code := m.Run()
+	log.SetLevel(log.InfoLevel)
+	os.Exit(code)
 }
 
 func TestDescription(t *testing.T) {
@@ -66,7 +67,7 @@ func TestRunPipeFail(t *testing.T) {
 			},
 		)
 		err := Pipe{}.Run(ctx)
-		require.Contains(t, err.Error(), "hook failed")
+		require.ErrorContains(t, err, "hook failed")
 	}
 }
 
