@@ -6,15 +6,15 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/client"
-	"github.com/goreleaser/goreleaser/internal/golden"
-	"github.com/goreleaser/goreleaser/internal/skips"
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/internal/testlib"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/client"
+	"github.com/goreleaser/goreleaser/v2/internal/golden"
+	"github.com/goreleaser/goreleaser/v2/internal/skips"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 	"github.com/stretchr/testify/require"
 )
 
@@ -109,7 +109,6 @@ func TestFullFormulae(t *testing.T) {
 	data.Caveats = []string{"Here are some caveats"}
 	data.Dependencies = []config.HomebrewDependency{{Name: "gtk+"}}
 	data.Conflicts = []string{"svn"}
-	data.Plist = "it works"
 	data.PostInstall = []string{`touch "/tmp/foo"`, `system "echo", "done"`}
 	data.CustomBlock = []string{"devel do", `  url "https://github.com/caarlos0/test/releases/download/v0.1.3/test_Darwin_x86_64.tar.gz"`, `  sha256 "1633f61598ab0791e213135923624eb342196b3494909c91899bcd0560f84c68"`, "end"}
 	data.Tests = []string{`system "#{bin}/{{.ProjectName}}", "-version"`}
@@ -148,7 +147,6 @@ func TestFormulaeSimple(t *testing.T) {
 	require.NoError(t, err)
 	assertDefaultTemplateData(t, formulae)
 	require.NotContains(t, formulae, "def caveats")
-	require.NotContains(t, formulae, "def plist;")
 }
 
 func TestSplit(t *testing.T) {
@@ -177,6 +175,29 @@ func TestFullPipe(t *testing.T) {
 				ctx.Config.Brews[0].Homepage = "https://github.com/goreleaser"
 			},
 		},
+		"with_header": {
+			prepare: func(ctx *context.Context) {
+				ctx.TokenType = context.TokenTypeGitHub
+				ctx.Config.Brews[0].Repository.Owner = "test"
+				ctx.Config.Brews[0].Repository.Name = "test"
+				ctx.Config.Brews[0].Homepage = "https://github.com/goreleaser"
+				ctx.Config.Brews[0].URLHeaders = []string{
+					`Authorization: bearer #{ENV["HOMEBREW_GITHUB_API_TOKEN"]}`,
+				}
+			},
+		},
+		"with_many_headers": {
+			prepare: func(ctx *context.Context) {
+				ctx.TokenType = context.TokenTypeGitHub
+				ctx.Config.Brews[0].Repository.Owner = "test"
+				ctx.Config.Brews[0].Repository.Name = "test"
+				ctx.Config.Brews[0].Homepage = "https://github.com/goreleaser"
+				ctx.Config.Brews[0].URLHeaders = []string{
+					"Accept: application/octet-stream",
+					`Authorization: bearer #{ENV["HOMEBREW_GITHUB_API_TOKEN"]}`,
+				}
+			},
+		},
 		"git_remote": {
 			prepare: func(ctx *context.Context) {
 				ctx.TokenType = context.TokenTypeGitHub
@@ -308,7 +329,6 @@ func TestFullPipe(t *testing.T) {
 							Description: "Run pipe test formula and FOO={{ .Env.FOO }}",
 							Caveats:     "don't do this {{ .ProjectName }}",
 							Test:        "system \"true\"\nsystem \"#{bin}/foo\", \"-h\"",
-							Plist:       `<xml>whatever</xml>`,
 							Dependencies: []config.HomebrewDependency{
 								{Name: "zsh", Type: "optional"},
 								{Name: "bash", Version: "3.2.57"},
@@ -721,14 +741,16 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 					ProjectName: name,
 					Brews: []config.Homebrew{
 						{
-							Name:         name,
-							Description:  "Run pipe test formula and FOO={{ .Env.FOO }}",
-							Caveats:      "don't do this {{ .ProjectName }}",
-							Test:         "system \"true\"\nsystem \"#{bin}/foo\", \"-h\"",
-							Plist:        `<xml>whatever</xml>`,
-							Dependencies: []config.HomebrewDependency{{Name: "zsh"}, {Name: "bash", Type: "recommended"}},
-							Conflicts:    []string{"gtk+", "qt"},
-							Install:      `bin.install "{{ .ProjectName }}"`,
+							Name:        name,
+							Description: "Run pipe test formula and FOO={{ .Env.FOO }}",
+							Caveats:     "don't do this {{ .ProjectName }}",
+							Test:        "system \"true\"\nsystem \"#{bin}/foo\", \"-h\"",
+							Dependencies: []config.HomebrewDependency{
+								{Name: "zsh"},
+								{Name: "bash", Type: "recommended"},
+							},
+							Conflicts: []string{"gtk+", "qt"},
+							Install:   `bin.install "{{ .ProjectName }}"`,
 							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
@@ -1084,6 +1106,7 @@ func TestRunPipePullRequest(t *testing.T) {
 	require.NoError(t, publishAll(ctx, client))
 	require.True(t, client.CreatedFile)
 	require.True(t, client.OpenedPullRequest)
+	require.True(t, client.SyncedFork)
 	golden.RequireEqualRb(t, []byte(client.Content))
 }
 
@@ -1207,8 +1230,7 @@ func TestDefault(t *testing.T) {
 		ProjectName: "myproject",
 		Brews: []config.Homebrew{
 			{
-				Plist: "<xml>... whatever</xml>",
-				Tap:   repo,
+				Repository: repo,
 			},
 		},
 	}, testctx.GitHubTokenType)
@@ -1218,7 +1240,6 @@ func TestDefault(t *testing.T) {
 	require.NotEmpty(t, ctx.Config.Brews[0].CommitAuthor.Email)
 	require.NotEmpty(t, ctx.Config.Brews[0].CommitMessageTemplate)
 	require.Equal(t, repo, ctx.Config.Brews[0].Repository)
-	require.True(t, ctx.Deprecated)
 }
 
 func TestGHFolder(t *testing.T) {
