@@ -3,6 +3,11 @@
   {{- if eq $element.Arch "all" }}
   url "{{ $element.DownloadURL }}"
   {{- if .DownloadStrategy }}, using: {{ .DownloadStrategy }}{{- end }}
+  {{- if .Headers }},
+    headers: [{{ printf "\n" }}
+      {{- join .Headers | indent 8 }}
+    ]
+  {{- end }}
   sha256 "{{ $element.SHA256 }}"
 
   def install
@@ -13,6 +18,11 @@
   {{- else if $.HasOnlyAmd64MacOsPkg }}
   url "{{ $element.DownloadURL }}"
   {{- if .DownloadStrategy }}, using: {{ .DownloadStrategy }}{{- end }}
+  {{- if .Headers }},
+    headers: [{{ printf "\n" }}
+      {{- join .Headers | indent 8 }}
+    ]
+  {{- end }}
   sha256 "{{ $element.SHA256 }}"
 
   def install
@@ -21,7 +31,7 @@
     {{- end }}
   end
 
-  if Hardware::CPU.arm?
+  on_arm do
     def caveats
       <<~EOS
         The darwin_arm64 architecture is not supported for the {{ $.Name }}
@@ -32,13 +42,18 @@
   end
   {{- else }}
   {{- if eq $element.Arch "amd64" }}
-  if Hardware::CPU.intel?
+  on_intel do
   {{- end }}
   {{- if eq $element.Arch "arm64" }}
-  if Hardware::CPU.arm?
+  on_arm do
   {{- end}}
     url "{{ $element.DownloadURL }}"
     {{- if .DownloadStrategy }}, using: {{ .DownloadStrategy }}{{- end }}
+    {{- if .Headers }},
+      headers: [{{ printf "\n" }}
+        {{- join .Headers | indent 8 }}
+      ]
+    {{- end }}
     sha256 "{{ $element.SHA256 }}"
 
     def install
