@@ -3,9 +3,9 @@ package discord
 import (
 	"testing"
 
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/internal/testlib"
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/stretchr/testify/require"
 )
 
@@ -56,3 +56,21 @@ func TestSkip(t *testing.T) {
 		require.False(t, Pipe{}.Skip(ctx))
 	})
 }
+
+func TestLive(t *testing.T) {
+	t.SkipNow()
+	t.Setenv("DISCORD_WEBHOOK_ID", "TODO")
+	t.Setenv("DISCORD_WEBHOOK_TOKEN", "TODO")
+
+	ctx := testctx.NewWithCfg(config.Project{
+		Announce: config.Announce{
+			Discord: config.Discord{
+				MessageTemplate: "test",
+				Enabled:         true,
+			},
+		},
+	})
+
+	require.NoError(t, Pipe{}.Default(ctx))
+	require.NoError(t, Pipe{}.Announce(ctx))
+}
