@@ -8,9 +8,9 @@ import (
 	"sync"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/gio"
-	"github.com/goreleaser/goreleaser/internal/logext"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/gio"
+	"github.com/goreleaser/goreleaser/v2/internal/logext"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 var (
@@ -43,7 +43,6 @@ type manifester interface {
 	Push(ctx *context.Context, manifest string, flags []string) (digest string, err error)
 }
 
-// nolint: unparam
 func runCommand(ctx *context.Context, dir, binary string, args ...string) error {
 	/* #nosec */
 	cmd := exec.CommandContext(ctx, binary, args...)
