@@ -11,15 +11,15 @@ import (
 	"time"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/gio"
-	"github.com/goreleaser/goreleaser/internal/ids"
-	"github.com/goreleaser/goreleaser/internal/pipe"
-	"github.com/goreleaser/goreleaser/internal/semerrgroup"
-	"github.com/goreleaser/goreleaser/internal/skips"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/gio"
+	"github.com/goreleaser/goreleaser/v2/internal/ids"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
+	"github.com/goreleaser/goreleaser/v2/internal/semerrgroup"
+	"github.com/goreleaser/goreleaser/v2/internal/skips"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 const (
@@ -118,8 +118,6 @@ func (Pipe) Publish(ctx *context.Context) error {
 func (Pipe) Run(ctx *context.Context) error {
 	g := semerrgroup.NewSkipAware(semerrgroup.New(ctx.Parallelism))
 	for i, docker := range ctx.Config.Dockers {
-		i := i
-		docker := docker
 		g.Go(func() error {
 			log := log.WithField("index", i)
 			log.Debug("looking for artifacts matching")
@@ -153,7 +151,7 @@ func (Pipe) Run(ctx *context.Context) error {
 		if pipe.IsSkip(err) {
 			return err
 		}
-		return fmt.Errorf("docker build failed: %w\nLearn more at https://goreleaser.com/errors/docker-build\n", err) // nolint:revive
+		return fmt.Errorf("docker build failed: %w\nLearn more at https://goreleaser.com/errors/docker-build\n", err) //nolint:revive
 	}
 	return nil
 }
@@ -273,7 +271,7 @@ func isBuildxContextError(out string) bool {
 }
 
 func processImageTemplates(ctx *context.Context, docker config.Docker) ([]string, error) {
-	// nolint:prealloc
+	//nolint:prealloc
 	var images []string
 	for _, imageTemplate := range docker.ImageTemplates {
 		image, err := tmpl.New(ctx).Apply(imageTemplate)
@@ -291,7 +289,7 @@ func processImageTemplates(ctx *context.Context, docker config.Docker) ([]string
 }
 
 func processBuildFlagTemplates(ctx *context.Context, docker config.Docker) ([]string, error) {
-	// nolint:prealloc
+	//nolint:prealloc
 	var buildFlags []string
 	for _, buildFlagTemplate := range docker.BuildFlagTemplates {
 		buildFlag, err := tmpl.New(ctx).Apply(buildFlagTemplate)
