@@ -12,9 +12,7 @@ import (
 // Pipe that writes the effective config file to dist.
 type Pipe struct{}
 
-func (Pipe) String() string {
-	return "writing effective config file"
-}
+func (Pipe) String() string { return "" }
 
 // Run the pipe.
 func (Pipe) Run(ctx *context.Context) (err error) {
@@ -23,6 +21,6 @@ func (Pipe) Run(ctx *context.Context) (err error) {
 	if err != nil {
 		return err
 	}
-	log.WithField("config", path).Info("writing")
+	log.WithField("path", path).Debug("writing effective configuration")
 	return os.WriteFile(path, bts, 0o644) //nolint: gosec
 }
