@@ -14,10 +14,10 @@ import (
 	"strings"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/logext"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/logext"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 // ErrReplaceWithProxy happens when the configuration has gomod.proxy enabled,
@@ -160,7 +160,7 @@ func proxyBuild(ctx *context.Context, build *config.Build) error {
 	log.Debugf("tidying")
 	cmd := exec.CommandContext(ctx, ctx.Config.GoMod.GoBinary, "get", ctx.ModulePath+"@"+ctx.Git.CurrentTag)
 	cmd.Dir = dir
-	cmd.Env = append(ctx.Config.GoMod.Env, os.Environ()...) //nolint: gocritic
+	cmd.Env = append(ctx.Config.GoMod.Env, os.Environ()...)
 	if out, err := cmd.CombinedOutput(); err != nil {
 		return newDetailedErrProxy(err, string(out))
 	}
