@@ -7,9 +7,9 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/internal/testlib"
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/stretchr/testify/require"
 )
 
@@ -17,7 +17,7 @@ func TestRun(t *testing.T) {
 	ctx := testctx.New()
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.NoError(t, Pipe{}.Run(ctx))
-	require.Equal(t, "github.com/goreleaser/goreleaser", ctx.ModulePath)
+	require.Equal(t, "github.com/goreleaser/goreleaser/v2", ctx.ModulePath)
 }
 
 func TestRunGoWork(t *testing.T) {
@@ -55,7 +55,7 @@ func TestRunCustomMod(t *testing.T) {
 	})
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.NoError(t, Pipe{}.Run(ctx))
-	require.Equal(t, "github.com/goreleaser/goreleaser", ctx.ModulePath)
+	require.Equal(t, "github.com/goreleaser/goreleaser/v2", ctx.ModulePath)
 }
 
 func TestCustomEnv(t *testing.T) {
@@ -75,6 +75,29 @@ func TestCustomEnv(t *testing.T) {
 	require.NoError(t, Pipe{}.Run(ctx))
 }
 
+func TestRunCustomDir(t *testing.T) {
+	dir := testlib.Mktmp(t)
+	require.NoError(t, os.MkdirAll(filepath.Join(dir, "src"), 0o755))
+	require.NoError(t, os.WriteFile(
+		filepath.Join(dir, "src/main.go"),
+		[]byte("package main\nfunc main() {println(0)}"),
+		0o666,
+	))
+	require.NoError(t, os.WriteFile(
+		filepath.Join(dir, "src/go.mod"),
+		[]byte("module foo"),
+		0o666,
+	))
+	ctx := testctx.NewWithCfg(config.Project{
+		GoMod: config.GoMod{
+			Dir: filepath.Join(dir, "src"),
+		},
+	})
+	require.NoError(t, Pipe{}.Default(ctx))
+	require.NoError(t, Pipe{}.Run(ctx))
+	require.Equal(t, "foo", ctx.ModulePath)
+}
+
 func TestRunOutsideGoModule(t *testing.T) {
 	dir := testlib.Mktmp(t)
 	require.NoError(t, os.WriteFile(
