@@ -26,6 +26,7 @@ import (
 	_ "github.com/goreleaser/nfpm/v2/apk"  // blank import to register the format
 	_ "github.com/goreleaser/nfpm/v2/arch" // blank import to register the format
 	_ "github.com/goreleaser/nfpm/v2/deb"  // blank import to register the format
+	_ "github.com/goreleaser/nfpm/v2/ipk"  // blank import to register the format
 	_ "github.com/goreleaser/nfpm/v2/rpm"  // blank import to register the format
 )
 
@@ -147,7 +148,7 @@ func isSupportedTermuxArch(goos, goarch string) bool {
 	if goos != "android" {
 		return false
 	}
-	for _, arch := range []string{"amd64", "arm64", "386"} {
+	for _, arch := range []string{"amd64", "arm64", "arm", "386"} {
 		if strings.HasPrefix(goarch, arch) {
 			return true
 		}
@@ -173,6 +174,7 @@ var termuxArchReplacer = strings.NewReplacer(
 	"386", "i686",
 	"amd64", "x86_64",
 	"arm64", "aarch64",
+	"arm6", "arm",
 )
 
 func create(ctx *context.Context, fpm config.NFPM, format string, artifacts []*artifact.Artifact) error {
@@ -435,6 +437,15 @@ func create(ctx *context.Context, fpm config.NFPM, format string, artifacts []*a
 					PostUpgrade: overridden.ArchLinux.Scripts.PostUpgrade,
 				},
 			},
+			IPK: nfpm.IPK{
+				ABIVersion:    overridden.IPK.ABIVersion,
+				AutoInstalled: overridden.IPK.AutoInstalled,
+				Alternatives:  overridden.IPK.ToNFPAlts(),
+				Essential:     overridden.IPK.Essential,
+				Predepends:    overridden.IPK.Predepends,
+				Tags:          overridden.IPK.Tags,
+				Fields:        overridden.IPK.Fields,
+			},
 		},
 	}
 
