@@ -3,20 +3,20 @@ package reddit
 import (
 	"testing"
 
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/internal/testlib"
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/stretchr/testify/require"
 )
 
 func TestStringer(t *testing.T) {
-	require.Equal(t, Pipe{}.String(), "reddit")
+	require.Equal(t, "reddit", Pipe{}.String())
 }
 
 func TestDefault(t *testing.T) {
 	ctx := testctx.New()
 	require.NoError(t, Pipe{}.Default(ctx))
-	require.Equal(t, ctx.Config.Announce.Reddit.TitleTemplate, defaultTitleTemplate)
+	require.Equal(t, defaultTitleTemplate, ctx.Config.Announce.Reddit.TitleTemplate)
 }
 
 func TestAnnounceInvalidURLTemplate(t *testing.T) {
