@@ -9,8 +9,8 @@ import (
 	"testing"
 	"time"
 
-	"github.com/goreleaser/goreleaser/internal/testlib"
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 	"github.com/stretchr/testify/require"
 )
 
@@ -18,9 +18,9 @@ func TestTarFile(t *testing.T) {
 	tmp := t.TempDir()
 	f, err := os.Create(filepath.Join(tmp, "test.tar"))
 	require.NoError(t, err)
-	defer f.Close() // nolint: errcheck
+	defer f.Close()
 	archive := New(f)
-	defer archive.Close() // nolint: errcheck
+	defer archive.Close()
 
 	require.Error(t, archive.Add(config.File{
 		Source:      "../testdata/nope.txt",
@@ -73,7 +73,7 @@ func TestTarFile(t *testing.T) {
 
 	f, err = os.Open(f.Name())
 	require.NoError(t, err)
-	defer f.Close() // nolint: errcheck
+	defer f.Close()
 
 	info, err := f.Stat()
 	require.NoError(t, err)
@@ -112,9 +112,9 @@ func TestTarFileInfo(t *testing.T) {
 	now := time.Now().Truncate(time.Second)
 	f, err := os.Create(filepath.Join(t.TempDir(), "test.tar"))
 	require.NoError(t, err)
-	defer f.Close() // nolint: errcheck
+	defer f.Close()
 	archive := New(f)
-	defer archive.Close() // nolint: errcheck
+	defer archive.Close()
 
 	require.NoError(t, archive.Add(config.File{
 		Source:      "../testdata/foo.txt",
@@ -132,7 +132,7 @@ func TestTarFileInfo(t *testing.T) {
 
 	f, err = os.Open(f.Name())
 	require.NoError(t, err)
-	defer f.Close() // nolint: errcheck
+	defer f.Close()
 
 	var found int
 	r := tar.NewReader(f)
@@ -157,7 +157,7 @@ func TestTarFileInfo(t *testing.T) {
 
 func TestTarInvalidLink(t *testing.T) {
 	archive := New(io.Discard)
-	defer archive.Close() // nolint: errcheck
+	defer archive.Close()
 
 	require.NoError(t, archive.Add(config.File{
 		Source:      "../testdata/badlink.txt",
