@@ -13,8 +13,8 @@ import (
 	"strings"
 	"time"
 
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
 )
 
 // GitInfo includes tags and diffs used in some point.
@@ -69,9 +69,18 @@ const (
 	TokenTypeGitea TokenType = "gitea"
 )
 
+type Action uint8
+
+const (
+	ActionNone Action = iota
+	ActionBuild
+	ActionRelease
+)
+
 // Context carries along some data through the pipes.
 type Context struct {
 	stdctx.Context
+	Action            Action
 	Config            config.Project
 	Env               Env
 	Token             string
